diff --git a/htdocs/core/class/html.form.class.php b/htdocs/core/class/html.form.class.php
index bb022b7767c..58616a3574e 100644
--- a/htdocs/core/class/html.form.class.php
+++ b/htdocs/core/class/html.form.class.php
@@ -1618,9 +1618,11 @@ class Form
* @param int $socid Thirdparty Id (to get also price dedicated to this customer)
* @param string $showempty '' to not show empty line. Translation key to show an empty line. '1' show empty line with no text.
* @param int $forcecombo Force to use combo box
+ * @param string $morecss Add more css on select
+ * @param int $hidepriceinlabel 1=Hide prices in label
* @return void
*/
- function select_produits($selected='', $htmlname='productid', $filtertype='', $limit=20, $price_level=0, $status=1, $finished=2, $selected_input_value='', $hidelabel=0, $ajaxoptions=array(), $socid=0, $showempty='1', $forcecombo=0)
+ function select_produits($selected='', $htmlname='productid', $filtertype='', $limit=20, $price_level=0, $status=1, $finished=2, $selected_input_value='', $hidelabel=0, $ajaxoptions=array(), $socid=0, $showempty='1', $forcecombo=0, $morecss='', $hidepriceinlabel)
{
global $langs,$conf;
@@ -1660,28 +1662,30 @@ class Form
}
else
{
- print $this->select_produits_list($selected,$htmlname,$filtertype,$limit,$price_level,'',$status,$finished,0,$socid,$showempty,$forcecombo);
+ print $this->select_produits_list($selected,$htmlname,$filtertype,$limit,$price_level,'',$status,$finished,0,$socid,$showempty,$forcecombo,$morecss,$hidepriceinlabel);
}
}
/**
* Return list of products for a customer
*
* @param int $selected Preselected product
* @param string $htmlname Name of select html
* @param string $filtertype Filter on product type (''=nofilter, 0=product, 1=service)
* @param int $limit Limit on number of returned lines
* @param int $price_level Level of price to show
* @param string $filterkey Filter on product
* @param int $status -1=Return all products, 0=Products not on sell, 1=Products on sell
* @param int $finished Filter on finished field: 2=No filter
* @param int $outputmode 0=HTML select string, 1=Array
* @param int $socid Thirdparty Id (to get also price dedicated to this customer)
* @param string $showempty '' to not show empty line. Translation key to show an empty line. '1' show empty line with no text.
* @param int $forcecombo Force to use combo box
* @return array Array of keys for json
*/
- function select_produits_list($selected='',$htmlname='productid',$filtertype='',$limit=20,$price_level=0,$filterkey='',$status=1,$finished=2,$outputmode=0,$socid=0,$showempty='1',$forcecombo=0)
+ function select_produits_list($selected='',$htmlname='productid',$filtertype='',$limit=20,$price_level=0,$filterkey='',$status=1,$finished=2,$outputmode=0,$socid=0,$showempty='1',$forcecombo=0,$morecss='',$hidepriceinlabel=0)
{
global $langs,$conf,$user,$db;
@@ -1782,7 +1786,7 @@ class Form
$nodatarole=($comboenhancement?' data-role="none"':'');
}
- $out.='
@@ -1660,28 +1662,30 @@ class Form
* Return list of products for a customer
*
- * @param int $selected Preselected product
- * @param string $htmlname Name of select html
- * @param string $filtertype Filter on product type (''=nofilter, 0=product, 1=service)
- * @param int $limit Limit on number of returned lines
- * @param int $price_level Level of price to show
- * @param string $filterkey Filter on product
- * @param int $status -1=Return all products, 0=Products not on sell, 1=Products on sell
- * @param int $finished Filter on finished field: 2=No filter
- * @param int $outputmode 0=HTML select string, 1=Array
- * @param int $socid Thirdparty Id (to get also price dedicated to this customer)
- * @param string $showempty '' to not show empty line. Translation key to show an empty line. '1' show empty line with no text.
- * @param int $forcecombo Force to use combo box
- * @return array Array of keys for json
+ * @param int $selected Preselected product
+ * @param string $htmlname Name of select html
+ * @param string $filtertype Filter on product type (''=nofilter, 0=product, 1=service)
+ * @param int $limit Limit on number of returned lines
+ * @param int $price_level Level of price to show
+ * @param string $filterkey Filter on product
+ * @param int $status -1=Return all products, 0=Products not on sell, 1=Products on sell
+ * @param int $finished Filter on finished field: 2=No filter
+ * @param int $outputmode 0=HTML select string, 1=Array
+ * @param int $socid Thirdparty Id (to get also price dedicated to this customer)
+ * @param string $showempty '' to not show empty line. Translation key to show an empty line. '1' show empty line with no text.
+ * @param int $forcecombo Force to use combo box
+ * @param string $morecss Add more css on select
+ * @param int $hidepriceinlabel 1=Hide prices in label
+ * @return array Array of keys for json
*/